==> vradi-swing-0.0.1-sources.jar: com/jurismarches/vradi/ui/editors/VradiEditor.java <==
package com.jurismarches.vradi.ui.editors;

import com.jurismarches.vradi.ui.editors.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.ui.OfferEditHandler;
import jaxx.runtime.DataBindingListener;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class VradiEditor extends jaxx.runtime.swing.Table implements jaxx.runtime.JAXXObject {
    public static final Log log = LogFactory.getLog(com.jurismarches.vradi.ui.editors.VradiEditor.class);
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAK1Su24TQRS9XvyIYwyGiChAQElwyzipjSDIYEFkHsIIRbhh7JnEY+1jmJlNFgrEJ/AJ0NMg0VEhCmoKGsQvIERBi5iZtXdtWJQUuNhd3znnzLnn3tffoCAFrI5wFCER+op5FG1d3d6+0x/RgbpG5UAwrgIB8S/ngNODCknqUsGFXsfQG2N6oxV4PPCpP8VudmBeqiculUNKlYJzs4yBlI1uctyMeCgmqompLNWXP747L8jzVw5AxLW7vG5l5SBW2km+Aw4jCk7qm/Zww8X+rrYhmL+r/VZNreViKW9jjz6GZ1DqQJFjocUUrB2+Zath+RFXUKrfx32Xriu4OAg8NAoFkx4WgyGVaE9gwlDIECXMRIsemMJ1+4dzq1FUUN5h1CXGlIKaMYmMcRQbT2Fz9a0O7lN3Q/dnUBGS+xqA4qoBlRNsNb6wFfjKdjdLuIv9hCDg7Ey+enIonVwaba4HBRHqsoKl3t/DvqeP4jEv/TFmI2hPfy0ufH739W17eranMqFTq6kz5yLgVChmrj4eDzZUzG3cwrzZg7Kkrt5ru7fLGca642NtTt93wsZr6OgGlkMtUSh9ef9h8dGnI+C0Yd4NMGljg78JZTUUOoXAJRG/smkdHd2f08+a8aag4uGIeaHXZU91UMcuEazwSp/5RGd8OdJJLGckkdjplz/+XOi+2ZykkdPuTv8TniZSeAhF5rvMp3bXx2ucudsVLmlIgnRdsxY4Z941Pl6zM/Z5Prtd5k/aNaDVKDSvNevdfNUPLVXlgu5QISj5D2J5RSN1gMZvEx/f4RUFAAA=";
    private static final long serialVersionUID = 1L;
    protected java.util.List<Object> $activeBindings = new ArrayList<Object>();
    protected java.util.Map<String,Object> $bindingSources = new HashMap<String,Object>();
    protected Map<String,Object> $objectMap = new HashMap<String,Object>();
    protected java.util.Map<?,?> $previousValues = new java.util.HashMap<Object,Object>();
    protected final jaxx.runtime.JAXXContext delegateContext = new jaxx.runtime.context.DefaultJAXXContext();
    protected javax.swing.JPanel editorContent;
    protected java.lang.String fieldName;
    private javax.swing.JLabel $JLabel1;
    private VradiEditor $Table0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource5 = new DataBindingListener(this, "$JLabel1.text");

    /* begin raw body code */    
    protected OfferEditHandler getHandler() {
        return getContextValue(OfferEditHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public VradiEditor() {
        $initialize();
    }

    public VradiEditor(jaxx.runtime.JAXXContext parentContext) {
        jaxx.runtime.Util.initContext(this, parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("$JLabel1.text".equals($binding)) {    
            addPropertyChangeListener("fieldName", $DataSource5);
        }
        processDataBinding($binding);
    }

    @Override
    public void firePropertyChange(String propertyName, Object oldValue, Object newValue) {
        super.firePropertyChange(propertyName, oldValue, newValue);
    }

    @Override
    public Map<String,Object> get$objectMap() {
        return $objectMap;
    }

    @Override
    public java.lang.Object getObjectById(String id) {
        return $objectMap.get(id);
    }

    @Override
    public void processDataBinding(String dest) {
        processDataBinding(dest, false);
    }

    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("$JLabel1.text".equals($dest)) {
                $JLabel1.setText(_(getFieldName()));
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("$JLabel1.text".equals($binding)) {    
            removePropertyChangeListener("fieldName", $DataSource5);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXContext implementation ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public <T> T getContextValue(Class<T> clazz) {
        return delegateContext.getContextValue(clazz, null);
    }

    @Override
    public <T> T getContextValue(Class<T> clazz, String name) {
        return delegateContext.getContextValue(clazz, name);
    }

    @Override
    public jaxx.runtime.JAXXContext getDelegateContext() {
        return delegateContext;
    }

    @Override
    public <O extends Container> O getParentContainer(Class<O> clazz) {
        return Util.getParentContainer(this, clazz);
    }

    @Override
    public <O extends Container> O getParentContainer(Object source, Class<O> clazz) {
        return Util.getParentContainer(source, clazz);
    }

    @Override
    public <T> void removeContextValue(Class<T> clazz) {
        delegateContext.removeContextValue(clazz, null);
    }

    @Override
    public <T> void removeContextValue(Class<T> clazz, String name) {
        delegateContext.removeContextValue(clazz, name);
    }

    @Override
    public <T> void setContextValue(T o) {
        delegateContext.setContextValue(o, null);
    }

    @Override
    public <T> void setContextValue(T o, String name) {
        delegateContext.setContextValue(o, name);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.util.List<Object> get$activeBindings() {
        return $activeBindings;
    }

    public java.util.Map<String,Object> get$bindingSources() {
        return $bindingSources;
    }

    public javax.swing.JPanel getEditorContent() {
        return editorContent;
    }

    public java.lang.String getFieldName() {
        return fieldName;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setFieldName(java.lang.String newValue) {
        java.lang.String oldValue = this.fieldName;
        this.fieldName = newValue;
        firePropertyChange("fieldName", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- protected acessors methods ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    protected javax.swing.JLabel get$JLabel1() {
        return $JLabel1;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        // inline complete setup of $Table0
        add($JLabel1, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, 10, 0, new Insets(0, 0, 0, 0), 0, 0));
        add(editorContent, new GridBagConstraints(1, 0, 1, 1, 1.0, 1.0, 10, 1, new Insets(0, 0, 0, 0), 0, 0));
        // init data bindings
        $JLabel1.setMaximumSize(new Dimension(100,10));
        $JLabel1.setMinimumSize(new Dimension(100,10));
        $JLabel1.setPreferredSize(new Dimension(100,10));
        applyDataBinding("$JLabel1.text");
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$Table0", this);
        createFieldName();
        // inline creation of $JLabel1
        $objectMap.put("$JLabel1", $JLabel1 = new javax.swing.JLabel());
        $JLabel1.setName("$JLabel1");
        createEditorContent();
        // inline creation of $Table0
        setName("$Table0");
        
        $completeSetup();
    }

    protected void createEditorContent() {
        $objectMap.put("editorContent", editorContent = new javax.swing.JPanel());
        editorContent.setName("editorContent");
    }

    protected void createFieldName() {
        $objectMap.put("fieldName", fieldName = "");
    }

}

==> vradi-swing-0.0.2-sources.jar: com/jurismarches/vradi/ui/editors/VradiEditor.java <==
package com.jurismarches.vradi.ui.editors;

import com.jurismarches.vradi.ui.editors.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.ui.OfferEditHandler;
import jaxx.runtime.DataBindingListener;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class VradiEditor extends jaxx.runtime.swing.Table implements jaxx.runtime.JAXXObject {
    public static final Log log = LogFactory.getLog(com.jurismarches.vradi.ui.editors.VradiEditor.class);
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAK1Tu24TQRS9XvyIYxxCIqIgjGSIRccYaiMIMlgQmYcwQhFuGHsm8Vi7s8PMbLJQID6BT4CeBomOClFQU9AgfgEhClrEzPixNixKCrbYx32cOffcs6+/QU5JODPEcYxkxDULKNq6ur19pzekfX2Nqr5kQocSRlfGA68LJTKNKw0b3bZtr4/b680wECGnfKa70YZFpZ/4VA0o1RpOz3f0lap3pulGLCI5QZ2SSkN9+eO794I8f+UBxMKws6NUD+pKJsm2wWNEw4o5aQ/Xfcx3DQ3J+K7hW7axpo+Vuo0D+hieQaENeYGlAdNw9vAjOwzXHwsNhdp93PPpBQ3n+2GAhpFkKsCyP6AK7UlMGIoYooRZadEDG7juPoRwGHkNxR1GfWJJaVi2JJEljkbEk7IyjTXlioV8wn8pSS7Uttq4R/2LZngLESO1b7rRKGqLijNAjkAz5NqNPt9wF/Npg4RTc+KbtaJkrYnumS7kZGTCGta7fzvhnkmNPLD+hwcsoMv+Wlv9/O7r29Zk8Vlz9onU0hnfmoUIGQoqNbNHHxttPdLMr9/CotGFoqK+Mb0zdSWFWGecNuTMeced9rYd3cBqYCByhS/vP6w9+nQEvBYs+iEmLWzrb0JRD6RRIfRJLK5sOkZH9xfMfdly01AKcMyCKOiwp0aopUsEa1ztMU6Mxpdjo0QlRYkpnV7x48/VzpvNiRoZw+7kP8sTRXIPIc+4zzh1P8LY46nGLwlFIxImXk5zd8Y+V8TYZhV3r6aPy/hkXFu0EUf2UXPc7du5Q0OVhaQ7VEpK/gNYVpuf5gCM31SsAr4yBQAA";
    private static final long serialVersionUID = 1L;
    protected java.util.List<Object> $activeBindings = new ArrayList<Object>();
    protected java.util.Map<String,Object> $bindingSources = new HashMap<String,Object>();
    protected Map<String,Object> $objectMap = new HashMap<String,Object>();
    protected java.util.Map<?,?> $previousValues = new java.util.HashMap<Object,Object>();
    protected final jaxx.runtime.JAXXContext delegateContext = new jaxx.runtime.context.DefaultJAXXContext();
    protected javax.swing.JPanel editorContent;
    protected java.lang.String extensionName;
    protected java.lang.String fieldName;
    private javax.swing.JLabel $JLabel1;
    private VradiEditor $Table0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource5 = new DataBindingListener(this, "$JLabel1.text");

    /* begin raw body code */    
    protected OfferEditHandler getHandler() {
        return getContextValue(OfferEditHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public VradiEditor() {
        $initialize();
    }

    public VradiEditor(jaxx.runtime.JAXXContext parentContext) {
        jaxx.runtime.Util.initContext(this, parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("$JLabel1.text".equals($binding)) {    
            addPropertyChangeListener("fieldName", $DataSource5);
        }
        processDataBinding($binding);
    }

    @Override
    public void firePropertyChange(String propertyName, Object oldValue, Object newValue) {
        super.firePropertyChange(propertyName, oldValue, newValue);
    }

    @Override
    public Map<String,Object> get$objectMap() {
        return $objectMap;
    }

    @Override
    public java.lang.Object getObjectById(String id) {
        return $objectMap.get(id);
    }

    @Override
    public void processDataBinding(String dest) {
        processDataBinding(dest, false);
    }

    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("$JLabel1.text".equals($dest)) {
                $JLabel1.setText(_(getFieldName()));
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("$JLabel1.text".equals($binding)) {    
            removePropertyChangeListener("fieldName", $DataSource5);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXContext implementation ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public <T> T getContextValue(Class<T> clazz) {
        return delegateContext.getContextValue(clazz, null);
    }

    @Override
    public <T> T getContextValue(Class<T> clazz, String name) {
        return delegateContext.getContextValue(clazz, name);
    }

    @Override
    public jaxx.runtime.JAXXContext getDelegateContext() {
        return delegateContext;
    }

    @Override
    public <O extends Container> O getParentContainer(Class<O> clazz) {
        return Util.getParentContainer(this, clazz);
    }

    @Override
    public <O extends Container> O getParentContainer(Object source, Class<O> clazz) {
        return Util.getParentContainer(source, clazz);
    }

    @Override
    public <T> void removeContextValue(Class<T> clazz) {
        delegateContext.removeContextValue(clazz, null);
    }

    @Override
    public <T> void removeContextValue(Class<T> clazz, String name) {
        delegateContext.removeContextValue(clazz, name);
    }

    @Override
    public <T> void setContextValue(T o) {
        delegateContext.setContextValue(o, null);
    }

    @Override
    public <T> void setContextValue(T o, String name) {
        delegateContext.setContextValue(o, name);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.util.List<Object> get$activeBindings() {
        return $activeBindings;
    }

    public java.util.Map<String,Object> get$bindingSources() {
        return $bindingSources;
    }

    public javax.swing.JPanel getEditorContent() {
        return editorContent;
    }

    public java.lang.String getExtensionName() {
        return extensionName;
    }

    public java.lang.String getFieldName() {
        return fieldName;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setExtensionName(java.lang.String newValue) {
        java.lang.String oldValue = this.extensionName;
        this.extensionName = newValue;
        firePropertyChange("extensionName", oldValue, newValue);
    }

    public void setFieldName(java.lang.String newValue) {
        java.lang.String oldValue = this.fieldName;
        this.fieldName = newValue;
        firePropertyChange("fieldName", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- protected acessors methods ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    protected javax.swing.JLabel get$JLabel1() {
        return $JLabel1;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        // inline complete setup of $Table0
        add($JLabel1, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, 10, 0, new Insets(0, 0, 0, 0), 0, 0));
        add(editorContent, new GridBagConstraints(1, 0, 1, 1, 1.0, 1.0, 10, 1, new Insets(0, 0, 0, 0), 0, 0));
        // init data bindings
        $JLabel1.setMaximumSize(new Dimension(100,10));
        $JLabel1.setMinimumSize(new Dimension(100,10));
        $JLabel1.setPreferredSize(new Dimension(100,10));
        applyDataBinding("$JLabel1.text");
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$Table0", this);
        createFieldName();
        createExtensionName();
        // inline creation of $JLabel1
        $objectMap.put("$JLabel1", $JLabel1 = new javax.swing.JLabel());
        $JLabel1.setName("$JLabel1");
        createEditorContent();
        // inline creation of $Table0
        setName("$Table0");
        
        $completeSetup();
    }

    protected void createEditorContent() {
        $objectMap.put("editorContent", editorContent = new javax.swing.JPanel());
        editorContent.setName("editorContent");
    }

    protected void createExtensionName() {
        $objectMap.put("extensionName", extensionName = "");
    }

    protected void createFieldName() {
        $objectMap.put("fieldName", fieldName = "");
    }

}
